==> haskell-fold-debounce-0.2.0.9-129-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fold-debounce.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 fold-debounce
version:              0.2.0.9
visibility:           public
id:                   fold-debounce-0.2.0.9-DKnZu1GtC8OFcrg27CEKQt
key:                  fold-debounce-0.2.0.9-DKnZu1GtC8OFcrg27CEKQt
license:              BSD-3-Clause
maintainer:           Toshio Ito <debug.ito@gmail.com>
author:               Toshio Ito <debug.ito@gmail.com>
homepage:             https://github.com/debug-ito/fold-debounce
synopsis:             Fold multiple events that happen in a given period of time.
description:
    Fold multiple events that happen in a given period of time. See "Control.FoldDebounce".

category:             Control
abi:                  a1ba168a11af94d54353658fcca227c6
exposed:              True
exposed-modules:      Control.FoldDebounce
import-dirs:          /usr/lib/ghc-9.0.1/site-local/fold-debounce-0.2.0.9
library-dirs:         /usr/lib/ghc-9.0.1/site-local/fold-debounce-0.2.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/fold-debounce-0.2.0.9
hs-libraries:         HSfold-debounce-0.2.0.9-DKnZu1GtC8OFcrg27CEKQt
depends:
    base-4.15.0.0 data-default-class-0.1.2.0-LBmwYNzg9cwLSaLiX5AQfC
    stm-2.5.0.0 stm-delay-0.1.1.1-HNa7YEF2Pw12GHhJMYJNLq time-1.9.3

haddock-interfaces:
    /usr/share/doc/haskell-fold-debounce/html/fold-debounce.haddock

haddock-html:         /usr/share/doc/haskell-fold-debounce/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fold-debounce-0.2.0.9-136-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fold-debounce.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 fold-debounce
version:              0.2.0.9
visibility:           public
id:                   fold-debounce-0.2.0.9-8PdrtW8ZvyLBwNVp35r97B
key:                  fold-debounce-0.2.0.9-8PdrtW8ZvyLBwNVp35r97B
license:              BSD-3-Clause
maintainer:           Toshio Ito <debug.ito@gmail.com>
author:               Toshio Ito <debug.ito@gmail.com>
homepage:             https://github.com/debug-ito/fold-debounce
synopsis:             Fold multiple events that happen in a given period of time.
description:
    Fold multiple events that happen in a given period of time. See "Control.FoldDebounce".

category:             Control
abi:                  ff4d78e0673ba7783440160ced4732e5
exposed:              True
exposed-modules:      Control.FoldDebounce
import-dirs:          /usr/lib/ghc-9.0.2/site-local/fold-debounce-0.2.0.9
library-dirs:         /usr/lib/ghc-9.0.2/site-local/fold-debounce-0.2.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/fold-debounce-0.2.0.9
hs-libraries:         HSfold-debounce-0.2.0.9-8PdrtW8ZvyLBwNVp35r97B
depends:
    base-4.15.1.0 data-default-class-0.1.2.0-IxhEAzgy8931aXcEiJcyZO
    stm-2.5.0.0 stm-delay-0.1.1.1-6DJ9BCTtZCk3qd7rnEUrtM time-1.9.3

haddock-interfaces:
    /usr/share/doc/haskell-fold-debounce/html/fold-debounce.haddock

haddock-html:         /usr/share/doc/haskell-fold-debounce/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
